@@ -39,8 +39,10 @@ from copy import deepcopy
 
 from collections import OrderedDict
 
+
 import numpy as np
 import pandas as pd
+from pandas.io.sql import read_sql
 
 from lazy import lazy
 import six
@@ -79,7 +81,7 @@ class IdaDataBase(object):
     IdaDataFrame per connection.
     """
 
-    def __init__(self, dsn, uid='', pwd='', autocommit=True, verbose=False):
+    def __init__(self, dsn, uid='', pwd='',  autocommit=True, verbose=False):
         """
         Open a database connection.
 
@@ -167,6 +169,7 @@ class IdaDataBase(object):
 
         self.data_source_name = dsn
 
+
         # default value for _database_system is db2
         self._database_system = 'db2'
         # first delimiter before the parameters in the jdbc-url
@@ -191,7 +194,8 @@ class IdaDataBase(object):
 
         self._idadfs = []
 
-        if self._con_type == 'odbc':
+        if self._con_type == 'odbc' :
+
             self._connection_string = "DSN=%s; UID=%s; PWD=%s;LONGDATACOMPAT=1;"%(dsn,uid,pwd)
             """
             Workaround for CLOB retrieval: 
@@ -203,10 +207,13 @@ class IdaDataBase(object):
             SQL_DBCLOB to SQL_WLONGVARCHAR
             """
             import pyodbc
-            try :
+            try:
                 self._con = pyodbc.connect(self._connection_string)
             except Exception as e:
-                raise IdaDataBaseError(e.value[1])
+                 raise IdaDataBaseError(e.value[1])
+
+
+
 
             try:
                 self.ida_query("select count(*) from _V_OBJECT")
@@ -328,11 +335,21 @@ class IdaDataBase(object):
                     def _get_jdbc_driver_from_folders(folders):
                         jarpath = ''
                         if platform == 'win32':
-                            jarpaths = [fld.split(':')[1].replace('\\', '/') + "/"  + dl
-                                      for fld in folders for dl in driverlibs if os.path.isfile(fld + "/" + dl)]
+                            jarpaths = [fld.split(':')[1].replace('\\', '/') + "/" + dl
+                                        for fld in folders for dl in driverlibs if os.path.isfile(fld + "/" + dl)]
+                            if jarpaths == []:
+                                # check if classpath contains paths with wildcard "*" at the end
+                                jarpaths = [fld.split(':')[1].replace('\\', '/')[:-1] + dl
+                                            for fld in folders for dl in driverlibs if
+                                            fld[-1:] == '*' and os.path.isfile(fld + "/" + dl)]
                         else:
-                            jarpaths = [fld + "/"  + dl for fld in folders for dl in driverlibs if os.path.isfile(fld + "/" + dl)]
-
+                            jarpaths = [fld + "/" + dl for fld in folders for dl in driverlibs if
+                                        os.path.isfile(fld + "/" + dl)]
+                            if jarpaths == []:
+                                # check if classpath contains paths with wildcard "*" at the end
+                                jarpaths = [fld[:-1] + dl
+                                            for fld in folders for dl in driverlibs if
+                                            fld[-1:] == '*' and os.path.isfile(fld[:-1] + dl)]
                         if jarpaths:
                             return jarpaths[0]
                         
@@ -352,6 +369,7 @@ class IdaDataBase(object):
 
                 jpype.startJVM(jpype.getDefaultJVMPath(), '-Djava.class.path=%s' % jarpath)
 
+
             if self._is_netezza_system():
                 driver_not_found = ("HELP: The Netezza JDBC driver library 'nzjdbc3.jar' could not be found. "+
                                     "Please, follow the instructions on "+
@@ -1621,7 +1639,10 @@ class IdaDataBase(object):
             elif self._con_type == 'jdbc':
                 try:
                     import jaydebeapi
-                    self._con = jaydebeapi.connect('com.ibm.db2.jcc.DB2Driver', self._connection_string)
+                    if self._is_netezza_system():
+                        self._con = jaydebeapi.connect('org.netezza.Driver', self._connection_string)
+                    else:
+                        self._con = jaydebeapi.connect('com.ibm.db2.jcc.DB2Driver', self._connection_string)
                 except:
                     raise
                 else:
@@ -2266,19 +2287,17 @@ class IdaDataBase(object):
                 raise IdaDataBaseError(e.value[-1])
         elif self._con_type == "jdbc":
             # This avoids infinite recursions on Netezza due to reconnect calls in
-            sql.ida_query, sql.ida_scalar_query and sql._prepare_and_execute
+            # sql.ida_query, sql.ida_scalar_query and sql._prepare_and_execute
             if self._con._closed:
                 raise IdaDataBaseError("The connection is closed")
             try:
                 # Avoid infinite recursion
                 if self._is_netezza_system():
                     # On Netezza no result sets are returned after the first database error
-                    if sql.ida_query(self, "SELECT count(*) FROM _V_TABLE", True, True) == None:
+                    if read_sql("SELECT OBJID FROM _V_TABLE LIMIT 1", self._con) is None:
                         raise IdaDataBaseError("The connection is closed")
                 else:
-                    sql.ida_query(self,"SELECT distinct TABSCHEMA, TABNAME, OWNER,"+
-                                  " TYPE from SYSCAT.TABLES WHERE (OWNERTYPE = 'U')",
-                                  True, True)
+                    read_sql("SELECT TABLEID FROM SYSCAT.TABLES LIMIT 1", self._con)
             except Exception as e:
                 raise IdaDataBaseError("The connection is closed")
 
